@@ -14,7 +14,7 @@ async def get_process_run_profile(market, name):
 
 
 @router.post('/process/{market}/{name}', response_model=bool)
-async def process_enable(market, name, enable: bool = True):
+async def enable_proces(market, name, enable: bool = True):
     process_run_profile_repository = ItemHolder.get_entity(ProcessRunProfileRepository)
     process_run_profile = process_run_profile_repository.retrieve(name, market)
     process_run_profile.enabled = enable
